@@ -110,7 +110,6 @@ amiciSwigPath = os.path.join(amici_path, 'swig')
 amiciSrcPath = os.path.join(amici_path, 'src')
 amiciModulePath = os.path.dirname(__file__)
 
-hdf5_enabled = os.path.isfile(os.path.join(amici_path, 'amici.py'))
 has_clibs = any([os.path.isfile(os.path.join(amici_path, wrapper))
                  for wrapper in ['amici.py', 'amici_without_hdf5.py']])
 
@@ -128,12 +127,8 @@ __commit__ = _get_commit_hash()
 # Import SWIG module and swig-dependent submodules if required and available
 if not _imported_from_setup():
     if has_clibs:
-        if hdf5_enabled:
-            from . import amici
-            from .amici import *
-        else:
-            from . import amici_without_hdf5 as amici
-            from .amici_without_hdf5 import *
+        from . import amici
+        from .amici import *
 
         # These module require the swig interface and other dependencies
         from .numpy import ReturnDataView, ExpDataView
@@ -149,6 +144,8 @@ if not _imported_from_setup():
     from .sbml_import import SbmlImporter, assignmentRules2observables
     from .ode_export import ODEModel, ODEExporter
 
+hdf5_enabled = 'readSolverSettingsFromHDF5' in dir()
+
 
 def runAmiciSimulation(
         model: AmiciModel,
@@ -281,19 +278,32 @@ def import_model_module(module_name: str,
     """
     Import Python module of an AMICI model
 
-    :param module_name: Name of the python module for the model
-    :param module_path: Absolute path of the module
+    :param module_name: Name of the python package of the model
+    :param module_path: Absolute or relative path of the package directory
     :return: The model module
     """
 
     # ensure we will find the newly created module
     importlib.invalidate_caches()
 
-    with add_path(module_path):
-        # module already loaded?
-        if module_name in sys.modules:
-            # reload, because may just have been created
-            importlib.reload(sys.modules[module_name])
-            return sys.modules[module_name]
+    if not os.path.isdir(module_path):
+        raise ValueError(f"module_path '{module_path}' is not a directory.")
 
+    module_path = os.path.abspath(module_path)
+
+    # module already loaded?
+    if module_name in sys.modules:
+        # if a module with that name is already in sys.modules, we remove it,
+        # along with all other modules from that package. otherwise, there
+        # will be trouble if two different models with the same name are to
+        # be imported.
+        del sys.modules[module_name]
+        # collect first, don't delete while iterating
+        to_unload = {loaded_module_name for loaded_module_name in
+                     sys.modules.keys() if
+                     loaded_module_name.startswith(f"{module_name}.")}
+        for m in to_unload:
+            del sys.modules[m]
+
+    with add_path(module_path):
         return importlib.import_module(module_name)
