@@ -68,6 +68,39 @@ class AbstractModel {
                         const AmiVector &dx, int ip, const AmiVector &sx,
                         const AmiVector &sdx, AmiVector &sxdot) = 0;
 
+    /**
+     * @brief Residual function backward when running in steady state mode
+     * @param t time
+     * @param xB adjoint state
+     * @param dxB time derivative of state (DAE only)
+     * @param xBdot array to which values of the residual function will be
+     * written
+     */
+    virtual void fxBdot_ss(const realtype t, const AmiVector &xB,
+                           const AmiVector &dxB, AmiVector &xBdot) = 0;
+
+    /**
+     * @brief Sparse Jacobian function backward, steady state case
+     * @param JB sparse matrix to which values of the Jacobian will be written
+     */
+    virtual void fJSparseB_ss(SUNMatrix JB) = 0;
+
+    /**
+     * @brief Computes the sparse backward Jacobian for steadystate integration
+     * and writes it to the model member
+     * @param t timepoint
+     * @param cj scalar in Jacobian
+     * @param x Vector with the states
+     * @param dx Vector with the derivative states
+     * @param xB Vector with the adjoint states
+     * @param dxB Vector with the adjoint derivative states
+     * @param xBdot Vector with the adjoint state right hand side
+     */
+    virtual void writeSteadystateJB(const realtype t, realtype cj,
+                                    const AmiVector &x, const AmiVector &dx,
+                                    const AmiVector &xB, const AmiVector &dxB,
+                                    const AmiVector &xBdot) = 0;
+
     /**
      * @brief Dense Jacobian function
      * @param t time
@@ -81,6 +114,22 @@ class AbstractModel {
                     const AmiVector &dx, const AmiVector &xdot,
                     SUNMatrix J) = 0;
 
+    /**
+     * @brief Dense Jacobian function
+     * @param t time
+     * @param cj scaling factor (inverse of timestep, DAE only)
+     * @param x state
+     * @param dx time derivative of state (DAE only)
+     * @param xB Vector with the adjoint states
+     * @param dxB Vector with the adjoint derivative states
+     * @param xBdot Vector with the adjoint right hand side (unused)
+     * @param JB dense matrix to which values of the jacobian will be written
+     */
+    virtual void fJB(const realtype t, realtype cj, const AmiVector &x,
+                     const AmiVector &dx, const AmiVector &xB,
+                     const AmiVector &dxB, const AmiVector &xBdot,
+                     SUNMatrix JB) = 0;
+
     /**
      * @brief Sparse Jacobian function
      * @param t time
@@ -94,6 +143,22 @@ class AbstractModel {
                           const AmiVector &dx, const AmiVector &xdot,
                           SUNMatrix J) = 0;
 
+    /**
+     * @brief Sparse Jacobian function
+     * @param t time
+     * @param cj scaling factor (inverse of timestep, DAE only)
+     * @param x state
+     * @param dx time derivative of state (DAE only)
+     * @param xB Vector with the adjoint states
+     * @param dxB Vector with the adjoint derivative states
+     * @param xBdot Vector with the adjoint right hand side (unused)
+     * @param JB dense matrix to which values of the jacobian will be written
+     */
+    virtual void fJSparseB(const realtype t, realtype cj, const AmiVector &x,
+                           const AmiVector &dx, const AmiVector &xB,
+                           const AmiVector &dxB, const AmiVector &xBdot,
+                           SUNMatrix JB) = 0;
+
     /**
      * @brief Diagonal Jacobian function
      * @param t time
