@@ -479,25 +479,25 @@ class ExpData {
     int nmaxevent_{0};
 
     /** @brief observation timepoints (dimension: nt) */
-    std::vector<realtype> ts;
+    std::vector<realtype> ts_;
 
     /** @brief observed data (dimension: nt x nytrue, row-major) */
-    std::vector<realtype> observedData;
+    std::vector<realtype> observed_data_;
     /**
      * @brief standard deviation of observed data (dimension: nt x nytrue,
      * row-major)
      */
-    std::vector<realtype> observedDataStdDev;
+    std::vector<realtype> observed_data_std_dev_;
 
     /**
      * @brief observed events (dimension: nmaxevents x nztrue, row-major)
      */
-    std::vector<realtype> observedEvents;
+    std::vector<realtype> observed_events_;
     /**
      * @brief standard deviation of observed events/roots
      * (dimension: nmaxevents x nztrue, row-major)
      */
-    std::vector<realtype> observedEventsStdDev;
+    std::vector<realtype> observed_events_std_dev_;
 };
 
 /**
@@ -558,15 +558,15 @@ class ConditionContext : public ContextManager {
     void restore();
 
   private:
-    Model *model = nullptr;
-    std::vector<realtype> originalx0;
-    std::vector<realtype> originalsx0;
-    std::vector<realtype> originalParameters;
-    std::vector<realtype> originalFixedParameters;
-    std::vector<realtype> originalTimepoints;
-    std::vector<int> originalParameterList;
-    std::vector<amici::ParameterScaling> originalScaling;
-    bool originalReinitializeFixedParameterInitialStates;
+    Model *model_ = nullptr;
+    std::vector<realtype> original_x0_;
+    std::vector<realtype> original_sx0_;
+    std::vector<realtype> original_parameters_;
+    std::vector<realtype> original_fixed_parameters_;
+    std::vector<realtype> original_timepoints_;
+    std::vector<int> original_parameter_list_;
+    std::vector<amici::ParameterScaling> original_scaling_;
+    bool original_reinitialize_fixed_parameter_initial_states_;
 };
 
 } // namespace amici
