@@ -131,7 +131,7 @@ class SUNLinSolWrapper {
     int initialize();
 
     /** Wrapped solver */
-    SUNLinearSolver solver = nullptr;
+    SUNLinearSolver solver_ {nullptr};
 };
 
 
@@ -160,7 +160,7 @@ class SUNLinSolBand : public SUNLinSolWrapper {
 
   private:
     /** Matrix A for solver, only if created by here. */
-    SUNMatrixWrapper A;
+    SUNMatrixWrapper A_;
 };
 
 
@@ -179,7 +179,7 @@ class SUNLinSolDense : public SUNLinSolWrapper {
 
   private:
     /** Matrix A for solver, only if created by here. */
-    SUNMatrixWrapper A;
+    SUNMatrixWrapper A_;
 };
 
 
@@ -233,7 +233,7 @@ class SUNLinSolKLU : public SUNLinSolWrapper {
 
   private:
     /** Sparse matrix A for solver, only if created by here. */
-    SUNMatrixWrapper A;
+    SUNMatrixWrapper A_;
 };
 
 #ifdef SUNDIALS_SUPERLUMT
@@ -727,7 +727,7 @@ class SUNNonLinSolWrapper {
      * @return
      */
     int Solve(N_Vector y0, N_Vector y, N_Vector w, realtype tol,
-              booleantype callLSetup, void *mem);
+              bool callLSetup, void *mem);
 
     /**
      * @brief Set function to evaluate the nonlinear residual function F(y) = 0
