@@ -210,10 +210,10 @@ class SUNMatrixWrapper {
     /**
      * @brief CSC matrix to which all methods are applied
      */
-    SUNMatrix matrix = nullptr;
-    realtype *data_ptr = nullptr;
-    sunindextype *indexptrs_ptr = nullptr;
-    sunindextype *indexvals_ptr = nullptr;
+    SUNMatrix matrix_ {nullptr};
+    realtype *data_ptr_ {nullptr};
+    sunindextype *indexptrs_ptr_ {nullptr};
+    sunindextype *indexvals_ptr_ {nullptr};
 };
 
 } // namespace amici
