@@ -23,6 +23,9 @@ from sympy.logic.boolalg import BooleanTrue as spTrue
 from sympy.logic.boolalg import BooleanFalse as spFalse
 from sympy.printing.mathml import MathMLContentPrinter
 
+# the following import can be removed if sympy PR #19958 is merged
+from mpmath.libmp import repr_dps, to_str as mlib_to_str
+
 
 class SBMLException(Exception):
     pass
@@ -257,7 +260,7 @@ class SbmlImporter:
             algorithm to compute steadystate sensitivities.
 
         :param simplify:
-            see :meth:`ODEModel._simplify`
+            see :attr:`ODEModel._simplify`
         """
         set_log_level(logger, verbose)
 
@@ -589,6 +592,7 @@ class SbmlImporter:
                 locals=self.local_symbols)
             formula = _parse_special_functions(formula)
             _check_unsupported_functions(formula, 'Rule')
+            formula = self._replace_reactions_in_rule_formula(rule, formula)
             ###
 
             # Species rules are processed first, to avoid processing
@@ -989,6 +993,7 @@ class SbmlImporter:
                 locals=self.local_symbols)
             formula = _parse_special_functions(formula)
             _check_unsupported_functions(formula, 'Rule')
+            formula = self._replace_reactions_in_rule_formula(rule, formula)
 
             if variable in stoichvars:
                 self.stoichiometric_matrix = \
@@ -1499,6 +1504,52 @@ class SbmlImporter:
                     f'Encountered currently unsupported element id {constant}!'
                 )
 
+    def _replace_reactions_in_rule_formula(self,
+                                           rule: sbml.Rule,
+                                           formula: sp.Expr):
+        """
+        SBML allows reaction IDs in rules, which should be interpreted as the
+        reaction rate.
+
+        An assignment or rate "...rule cannot be defined for a species that is
+        created or destroyed in a reaction, unless that species is defined as
+        a boundary condition in the model." Here, valid SBML is assumed, so
+        this restriction is not checked.
+
+        :param rule:
+            The SBML rule.
+
+        :param formula:
+            The `rule` formula that has already been parsed.
+            TODO create a function to parse rule formulae, as this logic is
+                 repeated a few times.
+
+        :return:
+            The formula, but reaction IDs are replaced with respective
+            reaction rate symbols.
+        """
+        reaction_ids = [r.getId() for r in self.sbml.getListOfReactions()]
+        reactions_in_rule_formula = {s
+                                     for s in formula.free_symbols
+                                     if str(s) in reaction_ids}
+        if reactions_in_rule_formula:
+            if rule.getTypeCode() not in (sbml.SBML_ASSIGNMENT_RULE,
+                                          sbml.SBML_RATE_RULE):
+                raise SBMLException('Currently, only assignment and rate'
+                                    ' rules have reaction replacement'
+                                    ' implemented.')
+
+        # Reactions are assigned indices in
+        # `sbml_import.py:_process_reactions()`, and these indices are used to
+        # generate flux variables in
+        # `ode_export.py:import_from_sbml_importer()`.
+        # These flux variables are anticipated here, as the symbols that
+        # represent the rates of reactions in the model.
+        subs = {r_sym: sp.Symbol(f'flux_r{reaction_ids.index(str(r_sym))}',
+                                 real=True)
+                for r_sym in reactions_in_rule_formula}
+        return formula.subs(subs)
+
 
 def get_rule_vars(rules: List[sbml.Rule],
                   local_symbols: Dict[str, sp.Symbol] = None) -> sp.Matrix:
@@ -1515,7 +1566,8 @@ def get_rule_vars(rules: List[sbml.Rule],
         Tuple of free symbolic variables in the formulas all provided rules
     """
     return sp.Matrix(
-        [sp.sympify(sbml.formulaToL3String(rule.getMath()),
+        [sp.sympify(_parse_logical_operators(
+                    sbml.formulaToL3String(rule.getMath())),
                     locals=local_symbols)
          for rule in rules if rule.getFormula() != '']
     ).free_symbols
@@ -1842,6 +1894,12 @@ class MathMLSbmlPrinter(MathMLContentPrinter):
         ci = self.dom.createElement(self.mathml_tag(sym))
         ci.appendChild(self.dom.createTextNode(sym.name))
         return ci
+    # _print_Float can be removed if sympy PR #19958 is merged 
+    def _print_Float(self, expr):
+        x = self.dom.createElement(self.mathml_tag(expr))
+        repr_expr = mlib_to_str(expr._mpf_, repr_dps(expr._prec))
+        x.appendChild(self.dom.createTextNode(repr_expr))
+        return x
     def doprint(self, expr):
         mathml = super().doprint(expr)
         mathml = '<math xmlns="http://www.w3.org/1998/Math/MathML">' + mathml + '</math>'
