@@ -192,7 +192,7 @@ def add_coverage_flags_if_required(cxx_flags: List[str],
         list of existing linker flags
     """
     if 'ENABLE_GCOV_COVERAGE' in os.environ and \
-            os.environ['ENABLE_GCOV_COVERAGE'] == 'TRUE':
+            os.environ['ENABLE_GCOV_COVERAGE'].upper() == 'TRUE':
         log.info("ENABLE_GCOV_COVERAGE was set to TRUE."
                  " Building AMICI with coverage symbols.")
         cxx_flags.extend(['-g', '-O0', '--coverage'])
@@ -219,11 +219,12 @@ def add_debug_flags_if_required(cxx_flags: List[str],
         linker_flags.extend(['-g'])
 
 
-def generate_swig_interface_files() -> None:
+def generate_swig_interface_files(with_hdf5: bool = None) -> None:
     """
     Compile the swig python interface to amici
     """
-    swig_outdir = '%s/amici' % os.path.abspath(os.getcwd())
+
+    swig_outdir = os.path.join(os.path.abspath(os.getcwd()), "amici")
     swig_exe = find_swig()
     swig_version = get_swig_version(swig_exe)
 
@@ -232,40 +233,29 @@ def generate_swig_interface_files() -> None:
         '-python',
         '-py3',
         '-threads',
-        '-Iamici/swig', '-Iamici/include',
+        f'-Iamici{os.sep}swig',
+        f'-Iamici{os.sep}include',
     ]
 
     log.info(f"Found SWIG version {swig_version}")
 
-    # Swig AMICI interface without HDF5 dependency
-    swig_cmd = [swig_exe,
-                *swig_args,
-                '-DAMICI_SWIG_WITHOUT_HDF5',
-                '-outdir', swig_outdir,
-                '-o', 'amici/amici_wrap_without_hdf5.cxx',
-                'amici/swig/amici.i']
+    # Are HDF5 includes available to generate the wrapper?
+    if with_hdf5 is None:
+        with_hdf5 = get_hdf5_config()['found']
+
+    if not with_hdf5:
+        swig_args.append('-DAMICI_SWIG_WITHOUT_HDF5')
 
     # Do we have -doxygen?
     if swig_version >= (4, 0, 0):
-        swig_cmd.insert(1, '-doxygen')
+        swig_args.append('-doxygen')
 
-    log.info(f"Running SWIG: {' '.join(swig_cmd)}")
-    sp = subprocess.run(swig_cmd, stdout=subprocess.PIPE,
-                        stderr=sys.stdout.buffer)
-    if not sp.returncode == 0:
-        raise AssertionError('Swigging AMICI failed:\n'
-                             + sp.stdout.decode('utf-8'))
-    shutil.move(os.path.join(swig_outdir, 'amici.py'),
-                os.path.join(swig_outdir, 'amici_without_hdf5.py'))
-
-    # Swig AMICI interface with HDF5 dependency
     swig_cmd = [swig_exe,
                 *swig_args,
                 '-outdir', swig_outdir,
-                '-o', 'amici/amici_wrap.cxx',
-                'amici/swig/amici.i']
-    if swig_version >= (4, 0, 0):
-        swig_cmd.insert(1, '-doxygen')
+                '-o', os.path.join("amici", "amici_wrap.cxx"),
+                os.path.join("amici", "swig", "amici.i")]
+
     log.info(f"Running SWIG: {' '.join(swig_cmd)}")
     sp = subprocess.run(swig_cmd, stdout=subprocess.PIPE,
                         stderr=sys.stdout.buffer)
