@@ -14,8 +14,8 @@ void Model_DAE::fJ(realtype t, realtype cj, N_Vector x, N_Vector dx,
     fdwdx(t, N_VGetArrayPointer(x_pos));
     SUNMatZero(J);
     fJ(SM_DATA_D(J), t, N_VGetArrayPointer(x_pos),
-       state.unscaledParameters.data(), state.fixedParameters.data(),
-       state.h.data(), cj, N_VGetArrayPointer(dx), w.data(), dwdx.data());
+       state_.unscaledParameters.data(), state_.fixedParameters.data(),
+       state_.h.data(), cj, N_VGetArrayPointer(dx), w_.data(), dwdx_.data());
 }
 
 void Model_DAE::fJSparse(const realtype t, const realtype cj,
@@ -30,9 +30,9 @@ void Model_DAE::fJSparse(realtype t, realtype cj, N_Vector x, N_Vector dx,
     fdwdx(t, N_VGetArrayPointer(x_pos));
     SUNMatZero(J);
     fJSparse(static_cast<SUNMatrixContent_Sparse>(SM_CONTENT_S(J)), t,
-             N_VGetArrayPointer(x_pos), state.unscaledParameters.data(),
-             state.fixedParameters.data(), state.h.data(), cj,
-             N_VGetArrayPointer(dx), w.data(), dwdx.data());
+             N_VGetArrayPointer(x_pos), state_.unscaledParameters.data(),
+             state_.fixedParameters.data(), state_.h.data(), cj,
+             N_VGetArrayPointer(dx), w_.data(), dwdx_.data());
 }
 
 void Model_DAE::fJSparseB(SUNMatrixContent_Sparse   /*JSparseB*/,
@@ -57,8 +57,8 @@ void Model_DAE::fJv(const realtype t, const AmiVector &x, const AmiVector &dx,
 void Model_DAE::fJv(realtype t, N_Vector x, N_Vector dx, N_Vector v,
                     N_Vector Jv, realtype cj) {
     N_VConst(0.0, Jv);
-    fJSparse(t, cj, x, dx, J.get());
-    J.multiply(Jv, v);
+    fJSparse(t, cj, x, dx, J_.get());
+    J_.multiply(Jv, v);
 }
 
 void Model_DAE::froot(const realtype t, const AmiVector &x, const AmiVector &dx,
@@ -71,8 +71,8 @@ void Model_DAE::froot(realtype t, N_Vector x, N_Vector dx,
     std::fill(root.begin(), root.end(), 0.0);
     auto x_pos = computeX_pos(x);
     froot(root.data(), t, N_VGetArrayPointer(x_pos),
-          state.unscaledParameters.data(), state.fixedParameters.data(),
-          state.h.data(), N_VGetArrayPointer(dx));
+          state_.unscaledParameters.data(), state_.fixedParameters.data(),
+          state_.h.data(), N_VGetArrayPointer(dx));
 }
 
 void Model_DAE::fxdot(const realtype t, const AmiVector &x, const AmiVector &dx,
@@ -85,8 +85,8 @@ void Model_DAE::fxdot(realtype t, N_Vector x, N_Vector dx, N_Vector xdot) {
     fw(t, N_VGetArrayPointer(x));
     N_VConst(0.0, xdot);
     fxdot(N_VGetArrayPointer(xdot), t, N_VGetArrayPointer(x_pos),
-          state.unscaledParameters.data(), state.fixedParameters.data(),
-          state.h.data(), N_VGetArrayPointer(dx), w.data());
+          state_.unscaledParameters.data(), state_.fixedParameters.data(),
+          state_.h.data(), N_VGetArrayPointer(dx), w_.data());
 }
 
 void Model_DAE::fJDiag(const realtype t, AmiVector &JDiag,
@@ -96,8 +96,8 @@ void Model_DAE::fJDiag(const realtype t, AmiVector &JDiag,
     fdwdx(t, N_VGetArrayPointer(x_pos));
     JDiag.set(0.0);
     fJDiag(JDiag.data(), t, N_VGetArrayPointer(x_pos),
-           state.unscaledParameters.data(), state.fixedParameters.data(),
-           state.h.data(), 0.0, dx.data(), w.data(), dwdx.data());
+           state_.unscaledParameters.data(), state_.fixedParameters.data(),
+           state_.h.data(), 0.0, dx.data(), w_.data(), dwdx_.data());
     if (!checkFinite(JDiag.getVector(), "Jacobian"))
         throw AmiException("Evaluation of fJDiag failed!");
 }
@@ -116,18 +116,18 @@ void Model_DAE::fdxdotdp(const realtype t, const N_Vector x,
         for (int ip = 0; ip < nplist(); ip++) {
             N_VConst(0.0, dxdotdp.getNVector(ip));
             fdxdotdp(dxdotdp.data(ip), t, N_VGetArrayPointer(x_pos),
-                     state.unscaledParameters.data(),
-                     state.fixedParameters.data(), state.h.data(), plist(ip),
-                     N_VGetArrayPointer(dx), w.data(), dwdp.data());
+                     state_.unscaledParameters.data(),
+                     state_.fixedParameters.data(), state_.h.data(), plist(ip),
+                     N_VGetArrayPointer(dx), w_.data(), dwdp_.data());
         }
     }
 }
 
 void Model_DAE::fM(realtype t, const N_Vector x) {
-    SUNMatZero(M.get());
+    SUNMatZero(M_.get());
     auto x_pos = computeX_pos(x);
-    fM(M.data(), t, N_VGetArrayPointer(x_pos), state.unscaledParameters.data(),
-       state.fixedParameters.data());
+    fM(M_.data(), t, N_VGetArrayPointer(x_pos), state_.unscaledParameters.data(),
+       state_.fixedParameters.data());
 }
 
 std::unique_ptr<Solver> Model_DAE::getSolver() {
@@ -184,9 +184,12 @@ void Model_DAE::fdxdotdp(realtype * /*dxdotdp*/, const realtype /*t*/,
                        __func__);
 }
 
+void Model_DAE::fM(realtype */*M*/, const realtype /*t*/, const realtype */*x*/,
+                   const realtype */*p*/, const realtype */*k*/){}
+
 void Model_DAE::fJB(const realtype t, realtype cj, const AmiVector &x,
-                     const AmiVector &dx, const AmiVector &xB,
-                     const AmiVector &dxB, const AmiVector & /*xBdot*/,
+                    const AmiVector &dx, const AmiVector &xB,
+                     const AmiVector &/*dxB*/, const AmiVector & /*xBdot*/,
                      SUNMatrix JB) {
     fJB(t, cj, x.getNVector(), dx.getNVector(), xB.getNVector(), dx.getNVector(), JB);
 }
@@ -198,9 +201,9 @@ void Model_DAE::fJB(realtype t, realtype cj, N_Vector x, N_Vector dx,
     fdwdx(t, N_VGetArrayPointer(x_pos));
     SUNMatZero(JB);
     fJB(SM_DATA_D(JB), t, N_VGetArrayPointer(x_pos),
-        state.unscaledParameters.data(), state.fixedParameters.data(),
-        state.h.data(), cj, N_VGetArrayPointer(xB), N_VGetArrayPointer(dx),
-        N_VGetArrayPointer(dxB), w.data(), dwdx.data());
+        state_.unscaledParameters.data(), state_.fixedParameters.data(),
+        state_.h.data(), cj, N_VGetArrayPointer(xB), N_VGetArrayPointer(dx),
+        N_VGetArrayPointer(dxB), w_.data(), dwdx_.data());
 }
 
 void Model_DAE::fJSparseB(const realtype t, realtype cj, const AmiVector &x,
@@ -216,25 +219,25 @@ void Model_DAE::fJSparseB(realtype t, realtype cj, N_Vector x, N_Vector dx,
     fdwdx(t, N_VGetArrayPointer(x_pos));
     SUNMatZero(JB);
     fJSparseB(static_cast<SUNMatrixContent_Sparse>(SM_CONTENT_S(JB)), t,
-              N_VGetArrayPointer(x_pos), state.unscaledParameters.data(),
-              state.fixedParameters.data(), state.h.data(), cj,
+              N_VGetArrayPointer(x_pos), state_.unscaledParameters.data(),
+              state_.fixedParameters.data(), state_.h.data(), cj,
               N_VGetArrayPointer(xB), N_VGetArrayPointer(dx),
-              N_VGetArrayPointer(dxB), w.data(), dwdx.data());
+              N_VGetArrayPointer(dxB), w_.data(), dwdx_.data());
 }
 
 void Model_DAE::fJvB(realtype t, N_Vector x, N_Vector dx, N_Vector xB,
                      N_Vector dxB, N_Vector vB, N_Vector JvB, realtype cj) {
     N_VConst(0.0, JvB);
-    fJSparseB(t, cj, x, dx, xB, dxB, J.get());
-    J.multiply(JvB, vB);
+    fJSparseB(t, cj, x, dx, xB, dxB, J_.get());
+    J_.multiply(JvB, vB);
 }
 
 void Model_DAE::fxBdot(realtype t, N_Vector x, N_Vector dx, N_Vector xB,
                        N_Vector dxB, N_Vector xBdot) {
     N_VConst(0.0, xBdot);
-    fJSparseB(t, 1.0, x, dx, xB, dxB, J.get());
+    fJSparseB(t, 1.0, x, dx, xB, dxB, J_.get());
     fM(t, x);
-    J.multiply(xBdot, xB);
+    J_.multiply(xBdot, xB);
 }
 
 void Model_DAE::fqBdot(realtype t, N_Vector x, N_Vector dx, N_Vector xB,
@@ -263,7 +266,7 @@ void Model_DAE::fxBdot_ss(realtype /*t*/, N_Vector xB, N_Vector /*dxB*/,
     /* Right hande side of the adjoint state for steady state computations.
      J is fixed (as x remeins in steady state), so the RHS becomes simple. */
     N_VConst(0.0, xBdot);
-    J.multiply(xBdot, xB);
+    J_.multiply(xBdot, xB);
     /* Mind the minus sign... */
     N_VScale(-1.0, xBdot, xBdot);
 }
@@ -277,7 +280,7 @@ void Model_DAE::fqBdot_ss(realtype /*t*/, N_Vector xB, N_Vector /*dxB*/,
 
 void Model_DAE::fJSparseB_ss(SUNMatrix JB) {
     /* Just pass the model Jacobian on to JB */
-    SUNMatCopy(J.get(), JB);
+    SUNMatCopy(J_.get(), JB);
 }
 
 void Model_DAE::writeSteadystateJB(const realtype t, realtype cj,
@@ -286,9 +289,9 @@ void Model_DAE::writeSteadystateJB(const realtype t, realtype cj,
                                    const AmiVector &xBdot) {
     /* Get backward Jacobian */
     fJSparseB(t, cj, x.getNVector(), dx.getNVector(), xB.getNVector(),
-              dxB.getNVector(), J.get());
+              dxB.getNVector(), J_.get());
     /* Switch sign, as we integrate forward in time, not backward */
-    J.scale(-1);
+    J_.scale(-1);
 }
 
 void Model_DAE::fsxdot(const realtype t, const AmiVector &x,
@@ -305,7 +308,7 @@ void Model_DAE::fsxdot(realtype t, N_Vector x, N_Vector dx, int ip, N_Vector sx,
         // the same for all remaining
         fM(t, x);
         fdxdotdp(t, x, dx);
-        fJSparse(t, 0.0, x, dx, J.get());
+        fJSparse(t, 0.0, x, dx, J_.get());
     }
 
     if (pythonGenerated) {
@@ -316,9 +319,9 @@ void Model_DAE::fsxdot(realtype t, N_Vector x, N_Vector dx, int ip, N_Vector sx,
         N_VScale(1.0, dxdotdp.getNVector(ip), sxdot);
     }
 
-    J.multiply(sxdot, sx);
+    J_.multiply(sxdot, sx);
     N_VScale(-1.0, sdx, sdx);
-    M.multiply(sxdot, sdx);
+    M_.multiply(sxdot, sdx);
     N_VScale(-1.0, sdx, sdx);
 }
 
