@@ -9,29 +9,29 @@
 namespace amici {
 
 SUNMatrixWrapper::SUNMatrixWrapper(int M, int N, int NNZ, int sparsetype)
-    : matrix(SUNSparseMatrix(M, N, NNZ, sparsetype)) {
+    : matrix_(SUNSparseMatrix(M, N, NNZ, sparsetype)) {
 
     if (sparsetype != CSC_MAT && sparsetype != CSR_MAT)
         throw std::invalid_argument("Invalid sparsetype. Must be CSC_MAT or "
                                     "CSR_MAT");
 
-    if (NNZ && !matrix)
+    if (NNZ && !matrix_)
         throw std::bad_alloc();
 
     update_ptrs();
 }
 
 SUNMatrixWrapper::SUNMatrixWrapper(int M, int N)
-    : matrix(SUNDenseMatrix(M, N)) {
-    if (M && N && !matrix)
+    : matrix_(SUNDenseMatrix(M, N)) {
+    if (M && N && !matrix_)
         throw std::bad_alloc();
 
     update_ptrs();
 }
 
 SUNMatrixWrapper::SUNMatrixWrapper(int M, int ubw, int lbw)
-    : matrix(SUNBandMatrix(M, ubw, lbw)) {
-    if (M && !matrix)
+    : matrix_(SUNBandMatrix(M, ubw, lbw)) {
+    if (M && !matrix_)
         throw std::bad_alloc();
 
     update_ptrs();
@@ -45,45 +45,45 @@ SUNMatrixWrapper::SUNMatrixWrapper(const SUNMatrixWrapper &A, realtype droptol,
 
     switch (SUNMatGetID(A.get())) {
     case SUNMATRIX_DENSE:
-        matrix = SUNSparseFromDenseMatrix(A.get(), droptol, sparsetype);
+        matrix_ = SUNSparseFromDenseMatrix(A.get(), droptol, sparsetype);
         break;
     case SUNMATRIX_BAND:
-        matrix = SUNSparseFromBandMatrix(A.get(), droptol, sparsetype);
+        matrix_ = SUNSparseFromBandMatrix(A.get(), droptol, sparsetype);
         break;
     default:
         throw std::invalid_argument("Invalid Matrix. Must be SUNMATRIX_DENSE or"
                                     " SUNMATRIX_BAND");
     }
 
-    if (!matrix)
+    if (!matrix_)
         throw std::bad_alloc();
 
     update_ptrs();
 }
 
-SUNMatrixWrapper::SUNMatrixWrapper(SUNMatrix mat) : matrix(mat) {
+SUNMatrixWrapper::SUNMatrixWrapper(SUNMatrix mat) : matrix_(mat) {
     update_ptrs();
 }
 
 SUNMatrixWrapper::~SUNMatrixWrapper() {
-    if (matrix)
-        SUNMatDestroy(matrix);
+    if (matrix_)
+        SUNMatDestroy(matrix_);
 }
 
 SUNMatrixWrapper::SUNMatrixWrapper(const SUNMatrixWrapper &other) {
-    if (!other.matrix)
+    if (!other.matrix_)
         return;
 
-    matrix = SUNMatClone(other.matrix);
-    if (!matrix)
+    matrix_ = SUNMatClone(other.matrix_);
+    if (!matrix_)
         throw std::bad_alloc();
 
-    SUNMatCopy(other.matrix, matrix);
+    SUNMatCopy(other.matrix_, matrix_);
     update_ptrs();
 }
 
 SUNMatrixWrapper::SUNMatrixWrapper(SUNMatrixWrapper &&other) {
-    std::swap(matrix, other.matrix);
+    std::swap(matrix_, other.matrix_);
     update_ptrs();
 }
 
@@ -95,26 +95,26 @@ SUNMatrixWrapper &SUNMatrixWrapper::operator=(const SUNMatrixWrapper &other) {
 
 SUNMatrixWrapper &SUNMatrixWrapper::
 operator=(SUNMatrixWrapper &&other) {
-    std::swap(matrix, other.matrix);
+    std::swap(matrix_, other.matrix_);
     update_ptrs();
     return *this;
 }
 
 realtype *SUNMatrixWrapper::data() const {
-    return data_ptr;
+    return data_ptr_;
 }
 
 sunindextype SUNMatrixWrapper::rows() const {
-    if (!matrix)
+    if (!matrix_)
         return 0;
 
-    switch (SUNMatGetID(matrix)) {
+    switch (SUNMatGetID(matrix_)) {
     case SUNMATRIX_DENSE:
-        return SM_ROWS_D(matrix);
+        return SM_ROWS_D(matrix_);
     case SUNMATRIX_SPARSE:
-        return SM_ROWS_S(matrix);
+        return SM_ROWS_S(matrix_);
     case SUNMATRIX_BAND:
-        return SM_ROWS_B(matrix);
+        return SM_ROWS_B(matrix_);
     case SUNMATRIX_CUSTOM:
         throw std::domain_error("Amici currently does not support custom matrix"
                                 " types.");
@@ -124,16 +124,16 @@ sunindextype SUNMatrixWrapper::rows() const {
 }
 
 sunindextype SUNMatrixWrapper::columns() const {
-    if (!matrix)
+    if (!matrix_)
         return 0;
 
-    switch (SUNMatGetID(matrix)) {
+    switch (SUNMatGetID(matrix_)) {
     case SUNMATRIX_DENSE:
-        return SM_COLUMNS_D(matrix);
+        return SM_COLUMNS_D(matrix_);
     case SUNMATRIX_SPARSE:
-        return SM_COLUMNS_S(matrix);
+        return SM_COLUMNS_S(matrix_);
     case SUNMATRIX_BAND:
-        return SM_COLUMNS_B(matrix);
+        return SM_COLUMNS_B(matrix_);
     case SUNMATRIX_CUSTOM:
         throw std::domain_error("Amici currently does not support custom matrix"
                                 " types.");
@@ -143,12 +143,12 @@ sunindextype SUNMatrixWrapper::columns() const {
 }
 
 sunindextype SUNMatrixWrapper::nonzeros() const {
-    if (!matrix)
+    if (!matrix_)
         return 0;
 
-    switch (SUNMatGetID(matrix)) {
+    switch (SUNMatGetID(matrix_)) {
     case SUNMATRIX_SPARSE:
-        return SM_NNZ_S(matrix);
+        return SM_NNZ_S(matrix_);
     default:
         throw std::domain_error("Non-zeros property only available for "
                                 "sparse matrices");
@@ -156,29 +156,29 @@ sunindextype SUNMatrixWrapper::nonzeros() const {
 }
 
 sunindextype *SUNMatrixWrapper::indexvals() const {
-    return indexvals_ptr;
+    return indexvals_ptr_;
 }
 
 sunindextype *SUNMatrixWrapper::indexptrs() const {
-    return indexptrs_ptr;
+    return indexptrs_ptr_;
 }
 
 int SUNMatrixWrapper::sparsetype() const {
-    if (SUNMatGetID(matrix) == SUNMATRIX_SPARSE)
-        return SM_SPARSETYPE_S(matrix);
+    if (SUNMatGetID(matrix_) == SUNMATRIX_SPARSE)
+        return SM_SPARSETYPE_S(matrix_);
     throw std::domain_error("Function only available for sparse matrices");
 }
 
 void SUNMatrixWrapper::reset() {
-    if (matrix)
-        SUNMatZero(matrix);
+    if (matrix_)
+        SUNMatZero(matrix_);
 }
 
 void SUNMatrixWrapper::scale(realtype a) {
-    if (matrix) {
+    if (matrix_) {
         int nonzeros_ = static_cast<int>(nonzeros());
         for (int i = 0; i < nonzeros_; ++i)
-            data_ptr[i] *= a;
+            data_ptr_[i] *= a;
     }
 }
 
@@ -189,7 +189,7 @@ void SUNMatrixWrapper::multiply(N_Vector c, const_N_Vector b) const {
 
 void SUNMatrixWrapper::multiply(gsl::span<realtype> c,
                                 gsl::span<const realtype> b) const {
-    if (!matrix)
+    if (!matrix_)
         return;
 
     sunindextype nrows = rows();
@@ -207,7 +207,7 @@ void SUNMatrixWrapper::multiply(gsl::span<realtype> c,
                                     + ") and elements in b ("
                                     + std::to_string(b.size()) + ")");
 
-    switch (SUNMatGetID(matrix)) {
+    switch (SUNMatGetID(matrix_)) {
     case SUNMATRIX_DENSE:
         amici_dgemv(BLASLayout::colMajor, BLASTranspose::noTrans,
                     static_cast<int>(nrows), static_cast<int>(ncols),
@@ -219,17 +219,17 @@ void SUNMatrixWrapper::multiply(gsl::span<realtype> c,
         switch (sparsetype()) {
         case CSC_MAT:
             for (sunindextype i = 0; i < ncols; ++i) {
-                for (sunindextype k = indexptrs_ptr[i]; k < indexptrs_ptr[i + 1];
+                for (sunindextype k = indexptrs_ptr_[i]; k < indexptrs_ptr_[i + 1];
                      ++k) {
-                    c[indexvals_ptr[k]] += data_ptr[k] * b[i];
+                    c[indexvals_ptr_[k]] += data_ptr_[k] * b[i];
                 }
             }
             break;
         case CSR_MAT:
             for (sunindextype i = 0; i < nrows; ++i) {
-                for (sunindextype k = indexptrs_ptr[i]; k < indexptrs_ptr[i + 1];
+                for (sunindextype k = indexptrs_ptr_[i]; k < indexptrs_ptr_[i + 1];
                      ++k) {
-                    c[i] += data_ptr[k] * b[indexvals_ptr[k]];
+                    c[i] += data_ptr_[k] * b[indexvals_ptr_[k]];
                 }
             }
             break;
@@ -261,7 +261,7 @@ void SUNMatrixWrapper::multiply(gsl::span<realtype> c,
                                 gsl::span<const realtype> b,
                                 gsl::span<const int> cols,
                                 bool transpose) const {
-    if (!matrix)
+    if (!matrix_)
         return;
 
     sunindextype nrows = rows();
@@ -293,7 +293,7 @@ void SUNMatrixWrapper::multiply(gsl::span<realtype> c,
                                         + std::to_string(b.size()) + ")");
     }
 
-    if (SUNMatGetID(matrix) != SUNMATRIX_SPARSE)
+    if (SUNMatGetID(matrix_) != SUNMATRIX_SPARSE)
         throw std::invalid_argument("Reordered multiply only implemented for "
                                     "sparse matrices, but A is not sparse");
 
@@ -304,39 +304,39 @@ void SUNMatrixWrapper::multiply(gsl::span<realtype> c,
     /* Carry out actual multiplication */
     if (transpose) {
         for (int i = 0; i < (int)cols.size(); ++i)
-            for (sunindextype k = indexptrs_ptr[cols[i]];
-                 k < indexptrs_ptr[cols[i] + 1]; ++k)
-                c[i] += data_ptr[k] * b[indexvals_ptr[k]];
+            for (sunindextype k = indexptrs_ptr_[cols[i]];
+                 k < indexptrs_ptr_[cols[i] + 1]; ++k)
+                c[i] += data_ptr_[k] * b[indexvals_ptr_[k]];
     } else {
         for (sunindextype i = 0; i < ncols; ++i)
-            for (sunindextype k = indexptrs_ptr[cols[i]];
-                 k < indexptrs_ptr[cols[i] + 1]; ++k)
-                c[indexvals_ptr[k]] += data_ptr[k] * b[i];
+            for (sunindextype k = indexptrs_ptr_[cols[i]];
+                 k < indexptrs_ptr_[cols[i] + 1]; ++k)
+                c[indexvals_ptr_[k]] += data_ptr_[k] * b[i];
     }
 }
 
 
 void SUNMatrixWrapper::sparse_multiply(SUNMatrixWrapper *C,
                                        SUNMatrixWrapper *B) const {
-    if (!matrix)
+    if (!matrix_)
         return;
 
     sunindextype nrows = rows();
     sunindextype ncols = columns();
 
-    if (SUNMatGetID(matrix) != SUNMATRIX_SPARSE)
+    if (SUNMatGetID(matrix_) != SUNMATRIX_SPARSE)
         throw std::invalid_argument("Matrix A not sparse in sparse_multiply");
 
     if (sparsetype() != CSC_MAT)
         throw std::invalid_argument("Matrix A not of type CSC_MAT");
 
-    if (SUNMatGetID(B->matrix) != SUNMATRIX_SPARSE)
+    if (SUNMatGetID(B->matrix_) != SUNMATRIX_SPARSE)
         throw std::invalid_argument("Matrix B not sparse in sparse_multiply");
 
     if (B->sparsetype() != CSC_MAT)
         throw std::invalid_argument("Matrix B not of type CSC_MAT");
 
-    if (SUNMatGetID(C->matrix) != SUNMATRIX_SPARSE)
+    if (SUNMatGetID(C->matrix_) != SUNMATRIX_SPARSE)
         throw std::invalid_argument("Matrix C not sparse in sparse_multiply");
 
     if (C->sparsetype() != CSC_MAT)
@@ -357,20 +357,20 @@ void SUNMatrixWrapper::sparse_multiply(SUNMatrixWrapper *C,
     /* Carry out actual multiplication */
     sunindextype iC_data = 0;
     for (sunindextype iC_col = 0; iC_col < C->columns(); ++iC_col) {
-        for(sunindextype iC_row = C->indexptrs_ptr[iC_col];
-            iC_row < C->indexptrs_ptr[iC_col + 1]; ++iC_row) {
+        for(sunindextype iC_row = C->indexptrs_ptr_[iC_col];
+            iC_row < C->indexptrs_ptr_[iC_col + 1]; ++iC_row) {
             // Current entry in C: (C.indexvals[iC_row], iC_col)
-            for(sunindextype iB_row = B->indexptrs_ptr[iC_col];
-                iB_row < B->indexptrs_ptr[iC_col + 1]; ++iB_row) {
+            for(sunindextype iB_row = B->indexptrs_ptr_[iC_col];
+                iB_row < B->indexptrs_ptr_[iC_col + 1]; ++iB_row) {
                 // Loop over column iC_col in B
-                sunindextype iA_col = B->indexvals_ptr[iB_row];
-                for (sunindextype iA_row = indexptrs_ptr[iA_col];
-                     iA_row < indexptrs_ptr[iA_col + 1]; ++iA_row)
+                sunindextype iA_col = B->indexvals_ptr_[iB_row];
+                for (sunindextype iA_row = indexptrs_ptr_[iA_col];
+                     iA_row < indexptrs_ptr_[iA_col + 1]; ++iA_row)
                     // loop over entries in column col_in_A
                     // if two entries match together, carry out multiplication
-                    if (indexvals_ptr[iA_row] == C->indexvals_ptr[iC_row])
-                        C->data_ptr[iC_data] +=
-                            data_ptr[iA_row] * B->data_ptr[iB_row];
+                    if (indexvals_ptr_[iA_row] == C->indexvals_ptr_[iC_row])
+                        C->data_ptr_[iC_data] +=
+                            data_ptr_[iA_row] * B->data_ptr_[iB_row];
             }
             iC_data++;
         }
@@ -379,30 +379,30 @@ void SUNMatrixWrapper::sparse_multiply(SUNMatrixWrapper *C,
 
 void SUNMatrixWrapper::zero()
 {
-    if(int res = SUNMatZero(matrix))
+    if(int res = SUNMatZero(matrix_))
         throw std::runtime_error("SUNMatrixWrapper::zero() failed with "
                                  + std::to_string(res));
 }
 
 void SUNMatrixWrapper::update_ptrs() {
-    if(!matrix)
+    if(!matrix_)
         return;
 
-    switch (SUNMatGetID(matrix)) {
+    switch (SUNMatGetID(matrix_)) {
     case SUNMATRIX_DENSE:
         if (columns() > 0 && rows() > 0)
-            data_ptr = SM_DATA_D(matrix);
+            data_ptr_ = SM_DATA_D(matrix_);
         break;
     case SUNMATRIX_SPARSE:
-        if (SM_NNZ_S(matrix) > 0) {
-            data_ptr = SM_DATA_S(matrix);
-            indexptrs_ptr = SM_INDEXPTRS_S(matrix);
-            indexvals_ptr = SM_INDEXVALS_S(matrix);
+        if (SM_NNZ_S(matrix_) > 0) {
+            data_ptr_ = SM_DATA_S(matrix_);
+            indexptrs_ptr_ = SM_INDEXPTRS_S(matrix_);
+            indexvals_ptr_ = SM_INDEXVALS_S(matrix_);
         }
         break;
     case SUNMATRIX_BAND:
         if (columns() > 0 && rows() > 0)
-            data_ptr = SM_DATA_B(matrix);
+            data_ptr_ = SM_DATA_B(matrix_);
         break;
     case SUNMATRIX_CUSTOM:
         throw std::domain_error("Amici currently does not support "
@@ -414,7 +414,7 @@ void SUNMatrixWrapper::update_ptrs() {
     }
 }
 
-SUNMatrix SUNMatrixWrapper::get() const { return matrix; }
+SUNMatrix SUNMatrixWrapper::get() const { return matrix_; }
 
 } // namespace amici
 
